@@ -177,7 +177,8 @@ class Mcdbot(discord.Client):
                     else:
                         raise NotImplementedError("discordpy gave us a channel we don't implement")
 
-                    split = list(filter(lambda i: i != '', message.content.split(" ").pop(0)))
+                    split = list(filter(lambda i: i != '', message.content.split(" ")))
+                    split.pop(0)
                     cmd = split.pop(0)
 
                     try:
